( cd usr/lib ; rm -rf libfreetype.so )
( cd usr/lib ; ln -sf libfreetype.so.6.3.18 libfreetype.so )
( cd usr/lib ; rm -rf libfreetype.so.6 )
( cd usr/lib ; ln -sf libfreetype.so.6.3.18 libfreetype.so.6 )
( cd usr/lib ; rm -rf libfontconfig.so.1 )
( cd usr/lib ; ln -sf libfontconfig.so.1.3.0 libfontconfig.so.1 )
( cd usr/lib ; rm -rf libfontconfig.so )
( cd usr/lib ; ln -sf libfontconfig.so.1.3.0 libfontconfig.so )
( cd usr/lib ; rm -rf libdrm.so.2 )
( cd usr/lib ; ln -sf libdrm.so.2.3.0 libdrm.so.2 )
( cd usr/lib ; rm -rf libdrm.so )
( cd usr/lib ; ln -sf libdrm.so.2.3.0 libdrm.so )
( cd usr/lib ; rm -rf libfontenc.so.1 )
( cd usr/lib ; ln -sf libfontenc.so.1.0.0 libfontenc.so.1 )
( cd usr/lib ; rm -rf libfontenc.so )
( cd usr/lib ; ln -sf libfontenc.so.1.0.0 libfontenc.so )
( cd usr/lib ; rm -rf libICE.so.6 )
( cd usr/lib ; ln -sf libICE.so.6.3.0 libICE.so.6 )
( cd usr/lib ; rm -rf libICE.so )
( cd usr/lib ; ln -sf libICE.so.6.3.0 libICE.so )
( cd usr/lib ; rm -rf libSM.so )
( cd usr/lib ; ln -sf libSM.so.6.0.0 libSM.so )
( cd usr/lib ; rm -rf libSM.so.6 )
( cd usr/lib ; ln -sf libSM.so.6.0.0 libSM.so.6 )
( cd usr/lib ; rm -rf libXau.so.6 )
( cd usr/lib ; ln -sf libXau.so.6.0.0 libXau.so.6 )
( cd usr/lib ; rm -rf libXau.so )
( cd usr/lib ; ln -sf libXau.so.6.0.0 libXau.so )
( cd usr/lib ; rm -rf libxcb-xinerama.so )
( cd usr/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so )
( cd usr/lib ; rm -rf libxcb-xfixes.so.0 )
( cd usr/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so.0 )
( cd usr/lib ; rm -rf libxcb-xf86dri.so )
( cd usr/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so )
( cd usr/lib ; rm -rf libxcb-xlib.so )
( cd usr/lib ; ln -sf libxcb-xlib.so.0.0.0 libxcb-xlib.so )
( cd usr/lib ; rm -rf libxcb-randr.so.0 )
( cd usr/lib ; ln -sf libxcb-randr.so.0.0.0 libxcb-randr.so.0 )
( cd usr/lib ; rm -rf libxcb-render.so )
( cd usr/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so )
( cd usr/lib ; rm -rf libxcb-xprint.so.0 )
( cd usr/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so.0 )
( cd usr/lib ; rm -rf libxcb.so )
( cd usr/lib ; ln -sf libxcb.so.1.0.0 libxcb.so )
( cd usr/lib ; rm -rf libxcb-glx.so.0 )
( cd usr/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so.0 )
( cd usr/lib ; rm -rf libxcb-shape.so.0 )
( cd usr/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so.0 )
( cd usr/lib ; rm -rf libxcb-randr.so )
( cd usr/lib ; ln -sf libxcb-randr.so.0.0.0 libxcb-randr.so )
( cd usr/lib ; rm -rf libxcb-xv.so.0 )
( cd usr/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so.0 )
( cd usr/lib ; rm -rf libxcb-render.so.0 )
( cd usr/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so.0 )
( cd usr/lib ; rm -rf libxcb-record.so.0 )
( cd usr/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so.0 )
( cd usr/lib ; rm -rf libxcb-xvmc.so )
( cd usr/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so )
( cd usr/lib ; rm -rf libxcb-dpms.so )
( cd usr/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so )
( cd usr/lib ; rm -rf libxcb-xevie.so.0 )
( cd usr/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so.0 )
( cd usr/lib ; rm -rf libxcb-xtest.so.0 )
( cd usr/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so.0 )
( cd usr/lib ; rm -rf libxcb-xinerama.so.0 )
( cd usr/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so.0 )
( cd usr/lib ; rm -rf libxcb-xtest.so )
( cd usr/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so )
( cd usr/lib ; rm -rf libxcb-xevie.so )
( cd usr/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so )
( cd usr/lib ; rm -rf libxcb-damage.so )
( cd usr/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so )
( cd usr/lib ; rm -rf libxcb-xf86dri.so.0 )
( cd usr/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so.0 )
( cd usr/lib ; rm -rf libxcb-xvmc.so.0 )
( cd usr/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so.0 )
( cd usr/lib ; rm -rf libxcb-screensaver.so )
( cd usr/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so )
( cd usr/lib ; rm -rf libxcb-sync.so )
( cd usr/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so )
( cd usr/lib ; rm -rf libxcb-glx.so )
( cd usr/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so )
( cd usr/lib ; rm -rf libxcb-shape.so )
( cd usr/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so )
( cd usr/lib ; rm -rf libxcb-sync.so.0 )
( cd usr/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so.0 )
( cd usr/lib ; rm -rf libxcb-xfixes.so )
( cd usr/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so )
( cd usr/lib ; rm -rf libxcb-composite.so.0 )
( cd usr/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so.0 )
( cd usr/lib ; rm -rf libxcb-record.so )
( cd usr/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so )
( cd usr/lib ; rm -rf libxcb-shm.so.0 )
( cd usr/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so.0 )
( cd usr/lib ; rm -rf libxcb-screensaver.so.0 )
( cd usr/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so.0 )
( cd usr/lib ; rm -rf libxcb.so.1 )
( cd usr/lib ; ln -sf libxcb.so.1.0.0 libxcb.so.1 )
( cd usr/lib ; rm -rf libxcb-dpms.so.0 )
( cd usr/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so.0 )
( cd usr/lib ; rm -rf libxcb-res.so.0 )
( cd usr/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so.0 )
( cd usr/lib ; rm -rf libxcb-res.so )
( cd usr/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so )
( cd usr/lib ; rm -rf libxcb-shm.so )
( cd usr/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so )
( cd usr/lib ; rm -rf libxcb-damage.so.0 )
( cd usr/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so.0 )
( cd usr/lib ; rm -rf libxcb-xprint.so )
( cd usr/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so )
( cd usr/lib ; rm -rf libxcb-xlib.so.0 )
( cd usr/lib ; ln -sf libxcb-xlib.so.0.0.0 libxcb-xlib.so.0 )
( cd usr/lib ; rm -rf libxcb-composite.so )
( cd usr/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so )
( cd usr/lib ; rm -rf libxcb-xv.so )
( cd usr/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so )
( cd usr/lib ; rm -rf libX11-xcb.so.1 )
( cd usr/lib ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so.1 )
( cd usr/lib ; rm -rf libX11-xcb.so )
( cd usr/lib ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so )
( cd usr/lib ; rm -rf libX11.so.6 )
( cd usr/lib ; ln -sf libX11.so.6.2.0 libX11.so.6 )
( cd usr/lib ; rm -rf libX11.so )
( cd usr/lib ; ln -sf libX11.so.6.2.0 libX11.so )
( cd usr/lib ; rm -rf libXt.so.6 )
( cd usr/lib ; ln -sf libXt.so.6.0.0 libXt.so.6 )
( cd usr/lib ; rm -rf libXt.so )
( cd usr/lib ; ln -sf libXt.so.6.0.0 libXt.so )
( cd usr/lib ; rm -rf libXfixes.so.3 )
( cd usr/lib ; ln -sf libXfixes.so.3.1.0 libXfixes.so.3 )
( cd usr/lib ; rm -rf libXfixes.so )
( cd usr/lib ; ln -sf libXfixes.so.3.1.0 libXfixes.so )
( cd usr/lib ; rm -rf libXext.so )
( cd usr/lib ; ln -sf libXext.so.6.4.0 libXext.so )
( cd usr/lib ; rm -rf libXext.so.6 )
( cd usr/lib ; ln -sf libXext.so.6.4.0 libXext.so.6 )
( cd usr/lib ; rm -rf libXv.so.1 )
( cd usr/lib ; ln -sf libXv.so.1.0.0 libXv.so.1 )
( cd usr/lib ; rm -rf libXv.so )
( cd usr/lib ; ln -sf libXv.so.1.0.0 libXv.so )
( cd usr/lib ; rm -rf libXss.so.1 )
( cd usr/lib ; ln -sf libXss.so.1.0.0 libXss.so.1 )
( cd usr/lib ; rm -rf libXss.so )
( cd usr/lib ; ln -sf libXss.so.1.0.0 libXss.so )
( cd usr/lib ; rm -rf libXpm.so.4 )
( cd usr/lib ; ln -sf libXpm.so.4.11.0 libXpm.so.4 )
( cd usr/lib ; rm -rf libXpm.so )
( cd usr/lib ; ln -sf libXpm.so.4.11.0 libXpm.so )
( cd usr/lib ; rm -rf libXtst.so.6 )
( cd usr/lib ; ln -sf libXtst.so.6.1.0 libXtst.so.6 )
( cd usr/lib ; rm -rf libXtst.so )
( cd usr/lib ; ln -sf libXtst.so.6.1.0 libXtst.so )
( cd usr/lib ; rm -rf libXxf86vm.so.1 )
( cd usr/lib ; ln -sf libXxf86vm.so.1.0.0 libXxf86vm.so.1 )
( cd usr/lib ; rm -rf libXxf86vm.so )
( cd usr/lib ; ln -sf libXxf86vm.so.1.0.0 libXxf86vm.so )
( cd usr/lib ; rm -rf libXi.so )
( cd usr/lib ; ln -sf libXi.so.6.0.0 libXi.so )
( cd usr/lib ; rm -rf libXi.so.6 )
( cd usr/lib ; ln -sf libXi.so.6.0.0 libXi.so.6 )
( cd usr/lib ; rm -rf libXinerama.so )
( cd usr/lib ; ln -sf libXinerama.so.1.0.0 libXinerama.so )
( cd usr/lib ; rm -rf libXinerama.so.1 )
( cd usr/lib ; ln -sf libXinerama.so.1.0.0 libXinerama.so.1 )
( cd usr/lib ; rm -rf libXmuu.so )
( cd usr/lib ; ln -sf libXmuu.so.1.0.0 libXmuu.so )
( cd usr/lib ; rm -rf libXmu.so.6 )
( cd usr/lib ; ln -sf libXmu.so.6.2.0 libXmu.so.6 )
( cd usr/lib ; rm -rf libXmuu.so.1 )
( cd usr/lib ; ln -sf libXmuu.so.1.0.0 libXmuu.so.1 )
( cd usr/lib ; rm -rf libXmu.so )
( cd usr/lib ; ln -sf libXmu.so.6.2.0 libXmu.so )
( cd usr/lib ; rm -rf libXp.so.6 )
( cd usr/lib ; ln -sf libXp.so.6.2.0 libXp.so.6 )
( cd usr/lib ; rm -rf libXp.so )
( cd usr/lib ; ln -sf libXp.so.6.2.0 libXp.so )
( cd usr/lib ; rm -rf libXcomposite.so.1 )
( cd usr/lib ; ln -sf libXcomposite.so.1.0.0 libXcomposite.so.1 )
( cd usr/lib ; rm -rf libXcomposite.so )
( cd usr/lib ; ln -sf libXcomposite.so.1.0.0 libXcomposite.so )
( cd usr/lib ; rm -rf libXdamage.so.1 )
( cd usr/lib ; ln -sf libXdamage.so.1.1.0 libXdamage.so.1 )
( cd usr/lib ; rm -rf libXdamage.so )
( cd usr/lib ; ln -sf libXdamage.so.1.1.0 libXdamage.so )
( cd usr/lib ; rm -rf libXfont.so )
( cd usr/lib ; ln -sf libXfont.so.1.4.1 libXfont.so )
( cd usr/lib ; rm -rf libXfont.so.1 )
( cd usr/lib ; ln -sf libXfont.so.1.4.1 libXfont.so.1 )
( cd usr/lib ; rm -rf libXaw.so.6 )
( cd usr/lib ; ln -sf libXaw6.so.6 libXaw.so.6 )
( cd usr/lib ; rm -rf libXaw.so.7 )
( cd usr/lib ; ln -sf libXaw7.so.7 libXaw.so.7 )
( cd usr/lib ; rm -rf libXaw.so.8 )
( cd usr/lib ; ln -sf libXaw8.so.8 libXaw.so.8 )
( cd usr/lib ; rm -rf libXaw6.so.6 )
( cd usr/lib ; ln -sf libXaw6.so.6.0.1 libXaw6.so.6 )
( cd usr/lib ; rm -rf libXaw7.so.7 )
( cd usr/lib ; ln -sf libXaw7.so.7.0.0 libXaw7.so.7 )
( cd usr/lib ; rm -rf libXaw8.so.8 )
( cd usr/lib ; ln -sf libXaw8.so.8.0.0 libXaw8.so.8 )
( cd usr/lib ; rm -rf libXaw.so )
( cd usr/lib ; ln -sf libXaw8.so libXaw.so )
( cd usr/lib ; rm -rf libXaw6.so )
( cd usr/lib ; ln -sf libXaw6.so.6.0.1 libXaw6.so )
( cd usr/lib ; rm -rf libXaw7.so )
( cd usr/lib ; ln -sf libXaw7.so.7.0.0 libXaw7.so )
( cd usr/lib ; rm -rf libXaw8.so )
( cd usr/lib ; ln -sf libXaw8.so.8.0.0 libXaw8.so )
( cd usr/lib ; rm -rf libXrender.so )
( cd usr/lib ; ln -sf libXrender.so.1.3.0 libXrender.so )
( cd usr/lib ; rm -rf libXrender.so.1 )
( cd usr/lib ; ln -sf libXrender.so.1.3.0 libXrender.so.1 )
( cd usr/lib ; rm -rf libXft.so.2 )
( cd usr/lib ; ln -sf libXft.so.2.1.13 libXft.so.2 )
( cd usr/lib ; rm -rf libXft.so )
( cd usr/lib ; ln -sf libXft.so.2.1.13 libXft.so )
( cd usr/lib ; rm -rf libXcursor.so )
( cd usr/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so )
( cd usr/lib ; rm -rf libXcursor.so.1 )
( cd usr/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so.1 )
( cd usr/lib ; rm -rf libXrandr.so )
( cd usr/lib ; ln -sf libXrandr.so.2.1.0 libXrandr.so )
( cd usr/lib ; rm -rf libXrandr.so.2 )
( cd usr/lib ; ln -sf libXrandr.so.2.1.0 libXrandr.so.2 )
( cd usr/lib ; rm -rf libXm.so.2 )
( cd usr/lib ; ln -sf libXm.so.2.0.1 libXm.so.2 )
( cd usr/lib ; rm -rf libMrm.so.2 )
( cd usr/lib ; ln -sf libMrm.so.2.0.1 libMrm.so.2 )
( cd usr/lib ; rm -rf libDtPrint.so )
( cd usr/lib ; ln -sf libDtPrint.so.1.0.0 libDtPrint.so )
( cd usr/lib ; rm -rf libMrm.so )
( cd usr/lib ; ln -sf libMrm.so.2.0.1 libMrm.so )
( cd usr/lib ; rm -rf libUil.so.2 )
( cd usr/lib ; ln -sf libUil.so.2.0.1 libUil.so.2 )
( cd usr/lib ; rm -rf libUil.so )
( cd usr/lib ; ln -sf libUil.so.2.0.1 libUil.so )
( cd usr/lib ; rm -rf libXm.so )
( cd usr/lib ; ln -sf libXm.so.2.0.1 libXm.so )
( cd usr/lib ; rm -rf libDtPrint.so.1 )
( cd usr/lib ; ln -sf libDtPrint.so.1.0.0 libDtPrint.so.1 )
